from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File

Cd_Hit_V0_1_0 = CommandToolBuilder(tool="cd_hit", base_command=["cd-hit"], inputs=[ToolInput(tag="in_input_filename_fasta", input_type=Boolean(optional=True), prefix="-i", doc=InputDocumentation(doc="input filename in fasta format, required, can be in .gz format")), ToolInput(tag="in_output_filename_required", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="output filename, required")), ToolInput(tag="in_sequence_identity_threshold", input_type=Boolean(optional=True), prefix="-c", doc=InputDocumentation(doc="sequence identity threshold, default 0.9\nthis is the default cd-hit's 'global sequence identity' calculated as:\nnumber of identical amino acids or bases in alignment\ndivided by the full length of the shorter sequence")), ToolInput(tag="in_use_identity_default", input_type=Boolean(optional=True), prefix="-G", doc=InputDocumentation(doc="use global sequence identity, default 1\nif set to 0, then use local sequence identity, calculated as :\nnumber of identical amino acids or bases in alignment\ndivided by the length of the alignment\nNOTE!!! don't use -G 0 unless you use alignment coverage controls\nsee options -aL, -AL, -aS, -AS")), ToolInput(tag="in_bandwidth_alignment_default", input_type=Boolean(optional=True), prefix="-b", doc=InputDocumentation(doc="band_width of alignment, default 20")), ToolInput(tag="in_memory_limit_mb", input_type=Boolean(optional=True), prefix="-M", doc=InputDocumentation(doc="memory limit (in MB) for the program, default 800; 0 for unlimitted;")), ToolInput(tag="in_number_threads_default", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc="number of threads, default 1; with 0, all CPUs will be used")), ToolInput(tag="in_wordlength_default_see", input_type=Boolean(optional=True), prefix="-n", doc=InputDocumentation(doc="word_length, default 5, see user's guide for choosing it")), ToolInput(tag="in_length_throwawaysequences_default", input_type=Boolean(optional=True), prefix="-l", doc=InputDocumentation(doc="length of throw_away_sequences, default 10")), ToolInput(tag="in_tolerance_redundance_default", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="tolerance for redundance, default 2")), ToolInput(tag="in_length_description_file", input_type=Boolean(optional=True), prefix="-d", doc=InputDocumentation(doc="length of description in .clstr file, default 20\nif set to 0, it takes the fasta defline and stops at first space")), ToolInput(tag="in_length_difference_cutoff_default", input_type=Boolean(optional=True), prefix="-s", doc=InputDocumentation(doc="length difference cutoff, default 0.0\nif set to 0.9, the shorter sequences need to be\nat least 90% length of the representative of the cluster")), ToolInput(tag="in_length_difference_cutoff_amino", input_type=Boolean(optional=True), prefix="-S", doc=InputDocumentation(doc="length difference cutoff in amino acid, default 999999\nif set to 60, the length difference between the shorter sequences\nand the representative of the cluster can not be bigger than 60")), ToolInput(tag="in_alignment_coverage_longer", input_type=Boolean(optional=True), prefix="-aL", doc=InputDocumentation(doc="alignment coverage for the longer sequence, default 0.0\nif set to 0.9, the alignment must covers 90% of the sequence")), ToolInput(tag="in_var_14", input_type=Boolean(optional=True), prefix="-AL", doc=InputDocumentation(doc="alignment coverage control for the longer sequence, default 99999999\nif set to 60, and the length of the sequence is 400,\nthen the alignment must be >= 340 (400-60) residues")), ToolInput(tag="in_alignment_coverage_shorter", input_type=Boolean(optional=True), prefix="-aS", doc=InputDocumentation(doc="alignment coverage for the shorter sequence, default 0.0\nif set to 0.9, the alignment must covers 90% of the sequence")), ToolInput(tag="in_var_16", input_type=Boolean(optional=True), prefix="-AS", doc=InputDocumentation(doc="alignment coverage control for the shorter sequence, default 99999999\nif set to 60, and the length of the sequence is 400,\nthen the alignment must be >= 340 (400-60) residues")), ToolInput(tag="in_minimal_alignment_coverage", input_type=Boolean(optional=True), prefix="-A", doc=InputDocumentation(doc="minimal alignment coverage control for the both sequences, default 0\nalignment must cover >= this value for both sequences")), ToolInput(tag="in_ul", input_type=Boolean(optional=True), prefix="-uL", doc=InputDocumentation(doc="maximum unmatched percentage for the longer sequence, default 1.0\nif set to 0.1, the unmatched region (excluding leading and tailing gaps)\nmust not be more than 10% of the sequence")), ToolInput(tag="in_us", input_type=Boolean(optional=True), prefix="-uS", doc=InputDocumentation(doc="maximum unmatched percentage for the shorter sequence, default 1.0\nif set to 0.1, the unmatched region (excluding leading and tailing gaps)\nmust not be more than 10% of the sequence")), ToolInput(tag="in_maximum_unmatched_length", input_type=Boolean(optional=True), prefix="-U", doc=InputDocumentation(doc="maximum unmatched length, default 99999999\nif set to 10, the unmatched region (excluding leading and tailing gaps)\nmust not be more than 10 bases")), ToolInput(tag="in_default_default_sequences", input_type=Boolean(optional=True), prefix="-B", doc=InputDocumentation(doc="1 or 0, default 0, by default, sequences are stored in RAM\nif set to 1, sequence are stored on hard drive\n!! No longer supported !!")), ToolInput(tag="in_default_set_print", input_type=Boolean(optional=True), prefix="-p", doc=InputDocumentation(doc="1 or 0, default 0\nif set to 1, print alignment overlap in .clstr file")), ToolInput(tag="in_default_cdhits_default", input_type=Boolean(optional=True), prefix="-g", doc=InputDocumentation(doc="1 or 0, default 0\nby cd-hit's default algorithm, a sequence is clustered to the first\ncluster that meet the threshold (fast cluster). If set to 1, the program\nwill cluster it into the most similar cluster that meet the threshold\n(accurate but slow mode)\nbut either 1 or 0 won't change the representatives of final clusters")), ToolInput(tag="in_sc", input_type=Boolean(optional=True), prefix="-sc", doc=InputDocumentation(doc="sort clusters by size (number of sequences), default 0, output clusters by decreasing length\nif set to 1, output clusters by decreasing size")), ToolInput(tag="in_sf", input_type=Boolean(optional=True), prefix="-sf", doc=InputDocumentation(doc="sort fasta/fastq by cluster size (number of sequences), default 0, no sorting\nif set to 1, output sequences by decreasing cluster size\nthis can be very slow if the input is in .gz format")), ToolInput(tag="in_bak", input_type=File(optional=True), prefix="-bak", doc=InputDocumentation(doc="backup cluster file (1 or 0, default 0)"))], outputs=[ToolOutput(tag="out_output_filename_required", output_type=File(optional=True), selector=InputSelector(input_to_select="in_output_filename_required", type_hint=File()), doc=OutputDocumentation(doc="output filename, required"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Cd_Hit_V0_1_0().translate("wdl", allow_empty_container=True)

